{ pkgs, ... }:
let
  pubkeys = import ../../modules/pubkeys.nix;
in
{
  imports = [
    (import "${builtins.fetchTarball "https://github.com/nix-community/home-manager/archive/release-20.09.tar.gz"}/nixos")
  ];

  users.users.simon = {
    isNormalUser = true;
    extraGroups = [
      "adbusers"
      "dialout"
      "docker"
      "libvirtd"
      "lp"
      "networkmanager"
      "video"
      "wheel"
    ];
    openssh.authorizedKeys.keys = [
      pubkeys."simon@nunotaba"
      pubkeys."simon@sayuri"
    ];
  };

  home-manager.useUserPackages = true;
  home-manager.useGlobalPkgs = true;

  home-manager.users.simon = { pkgs, ... }: {
    imports = [
      ./modules/alacritty.nix
      ./modules/ankisyncd.nix
      ./modules/sway.nix
      ./modules/zathura.nix
    ];

    gtk = {
      enable = true;
      font.name = "sans-serif 10";
      theme = {
        package = pkgs.gnome-themes-extra;
        name = "Adwaita";
      };
      iconTheme = {
        package = pkgs.gnome3.adwaita-icon-theme;
        name = "Adwaita";
      };
      # Tooltips remain visible when switching to another workspace
      gtk2.extraConfig = ''
        gtk-enable-tooltips = 0
      '';
    };

    xdg.mimeApps = {
      enable = true;
      defaultApplications = {
        "application/pdf" = "org.pwmt.zathura.desktop";
        "image/png" = "mpv.desktop";
        "image/jpeg" = "mpv.desktop";
      };
    };

    home.file = {
      ".config/htop/htoprc".text = ''
        color_scheme=6
      '';
    };
  };
}
